@@ -58,6 +58,11 @@ function dqReady() {
     //-- set preliminary timing info
     $(".elapsed").text("~" + String(ttk_elapsed) + "\u00a0sec");
 
+    //-- setup submit-on-enter for IE
+    $("#dqForm input[type='text']").keypress(function(e) {
+	if (e.which==13) { $("#dqForm").submit() }
+    });
+
     //-- set default query parameters
     profileSelectChange();
     var param = user_query;
